***Replication Package for:
*Do losses trigger deliberative reasoning?
*Judgment and Decision Making
*By: Jeffrey Carpenter and David Munro

clear all

*Set Your Directory to Replication Package Folder:
cap noi cd "/Users/..../Replication Package"

u "`c(pwd)'/Data/S1S2_Losses_Expanded.dta", clear

set more off

* Create some variables.
g treatment = fl_6_do

g treatment_n = 0
replace treatment_n = 1 if fl_6_do == "GainTreatment"
replace treatment_n = 2 if fl_6_do == "LossTreatment"
label define treat 0 "None" 1 "Gain" 2 "Loss"
label values treatment_n treat

g loss = treatment_n == 2
g gain = treatment_n == 1

g control = treatment_n == 0

g female = gender == "Female"
g nonbinary = gender == "Non-binary"

g black = race == "Black or African American"
g asian = race == "Asian"
g other = race == "American Indian or Alaska Native" | race == "Native Hawaiian or Pacific Islander" | race == "Other" | race == "Prefer not to disclose"

g hispanic = spanishhispanic == "Yes"

g college_or_more = education == "Bachelor's degree in college (4-year)" | education == "Master's degree" | education == "Professional degree (JD, MD)" | education == "Doctoral degree"

g advanced_degree = education == "Master's degree" | education == "Professional degree (JD, MD)" | education == "Doctoral degree"

g high_income = income == "$50,000 to $74,999" | income == "$75,000 to $99,999" | income == "$100,000 or more"

g gainXtime = time_constraint * gain
g lossXtime = time_constraint * loss

g crtincorrect = crtcorrect == 0 & crtintuit == 0

*Table 1 - Demographics Experiment 1
tabstat age female black asian hispanic advanced_degree high_income if time_constraint==0, by(treatment_n) statistics(mean)

*Table VIII - Demographics Experiment 2
tabstat age female black asian hispanic advanced_degree high_income if time_constraint==1, by(treatment_n) statistics(mean)

*Figure 1b - ECDF Time Spent
g crttime_pagesubmit_tc = crttime_pagesubmit
replace crttime_pagesubmit_tc = 60 if crttime_pagesubmit > 60

cumul crttime_pagesubmit_tc if time_constraint==0, gen(time_cum_tc) equal
cumul crttime_pagesubmit_tc if time_constraint==0 & treatment_n==1, gen(time_cum_gain_tc) equal
cumul crttime_pagesubmit_tc if time_constraint==0 & treatment_n==0, gen(time_cum_none_tc) equal
cumul crttime_pagesubmit_tc if time_constraint==0 & treatment_n==2, gen(time_cum_loss_tc) equal

twoway (line time_cum_loss_tc crttime_pagesubmit_tc, sort lpattern(solid)) (line time_cum_gain_tc crttime_pagesubmit_tc, sort lpattern(dash)) (line time_cum_none_tc crttime_pagesubmit_tc, sort lpattern(vshortdash))

ksmirnov crttime_pagesubmit_tc if time_constraint==0 & treatment_n!=2, by(treatment_n)
ksmirnov crttime_pagesubmit_tc if time_constraint==0 & treatment_n!=1, by(treatment_n)
ksmirnov crttime_pagesubmit_tc if time_constraint==0 & treatment_n!=0, by(treatment_n)

*Figure 1a - Mean time spent by treatment
cibar crttime_pagesubmit if time_constraint==0, over1(treatment_n)
ttest crttime_pagesubmit if time_constraint==0, by(control)
ttest crttime_pagesubmit if time_constraint==0 & treatment_n !=2, by(treatment_n)
ttest crttime_pagesubmit if time_constraint==0 & treatment_n !=1, by(treatment_n)
ttest crttime_pagesubmit if time_constraint==0 & treatment_n !=0, by(treatment_n)


*Table II - Time spent regressions
reg crttime_pagesubmit gain loss if time_constraint==0, r
lincom gain-loss
est sto T1

reg crttime_pagesubmit gain loss black asian other hispanic high_income advanced_degree if time_constraint==0, r
lincom gain-loss
est sto T2

reg crttime_pagesubmit gain loss black asian other hispanic high_income advanced_degree if time_constraint==0, cluster(participant)
lincom gain-loss
est sto T3

esttab T1 T2 T3, compress ar2 b(%10.3fc) se(%10.3fc) nonotes addnotes("Dependent variable is time spent answering (in seconds)." "Controls include race, education and income." "OLS with robust standard errors reported." "* p<0.10, ** p<0.05, *** p<0.01.") label replace star(* 0.105 ** 0.055 *** 0.015) /*
	*/ drop(black asian other hispanic high_income advanced_degree) mtitles("None" "Controls" "Ctrl+C") title("The effect of gains and losses on time spent answering.") /*
	*/ order()
	
*Figure 2 - Mean correct by treatment
cibar crtcorrect if time_constraint==0, over1(treatment_n)
ttest crtcorrect if time_constraint==0, by(control)
ttest crtcorrect if time_constraint==0 & treatment_n !=2, by(treatment_n)
ttest crtcorrect if time_constraint==0 & treatment_n !=1, by(treatment_n)
ttest crtcorrect if time_constraint==0 & treatment_n !=0, by(treatment_n)	
	

*Table III - Correct regressions
reg crtcorrect gain loss if time_constraint==0, r
lincom gain-loss
est sto C1

reg crtcorrect gain loss black asian other hispanic high_income advanced_degree if time_constraint==0, r
lincom gain-loss
est sto C2

reg crtcorrect gain loss black asian other hispanic high_income advanced_degree if time_constraint==0, cluster(participant)
lincom gain-loss
est sto C3

esttab C1 C2 C3, compress ar2 b(%10.3fc) se(%10.3fc) nonotes addnotes("Dependent variable is a correct response indicator." "Controls include race, education and income." "OLS with robust standard errors reported." "* p<0.10, ** p<0.05, *** p<0.01.") label replace star(* 0.105 ** 0.055 *** 0.015) /*
	*/ drop(black asian other hispanic high_income advanced_degree) mtitles("None" "Controls" "Ctrl+C") title("The effect of gains and losses on thinking correctly.") /*
	*/ order()	

*Figure 3 - Mean intuitive by treatment	
cibar crtintuit if time_constraint==0, over1(treatment_n)
ttest crtintuit if time_constraint==0, by(control)
ttest crtintuit if time_constraint==0 & treatment_n !=2, by(treatment_n)
ttest crtintuit if time_constraint==0 & treatment_n !=0, by(treatment_n)
ttest crtintuit if time_constraint==0 & treatment_n !=1, by(treatment_n)

*Table IV - Intuitive regressions
reg crtintuit gain loss if time_constraint==0, r
lincom gain-loss
est sto I1

reg crtintuit gain loss black asian other hispanic high_income advanced_degree if time_constraint==0, r
lincom gain-loss
est sto I2

reg crtintuit gain loss black asian other hispanic high_income advanced_degree if time_constraint==0, cluster(participant)
lincom gain-loss
est sto I3

esttab I1 I2 I3, compress ar2 b(%10.3fc) se(%10.3fc) nonotes addnotes("Dependent variable is an intuitive response indicator." "Controls include race, education and income." "OLS with robust standard errors reported." "* p<0.10, ** p<0.05, *** p<0.01.") label replace star(* 0.105 ** 0.055 *** 0.015) /*
	*/ drop(black asian other hispanic high_income advanced_degree) mtitles("None" "Controls" "Ctrl+C") title("The effect of gains and losses on thinking intuitively.") /*
	*/ order()
	
*Figure 4 - Mean unintuitive incorrect
g ans_type = .
replace ans_type = 0 if crtintuit==1
replace ans_type = 1 if crtincorrect==1
replace ans_type = 2 if crtcorrect==1

cibar crtincorrect if time_constraint==0, over1(treatment_n)
ttest crtincorrect if time_constraint==0 & treatment_n !=2, by(treatment_n)
ttest crtincorrect if time_constraint==0 & treatment_n !=0, by(treatment_n)
ttest crtincorrect if time_constraint==0 & treatment_n !=1, by(treatment_n)

*Figure 5 - Time spent by answer type
cibar crttime_pagesubmit if time_constraint==0, over1(ans_type) over2(treatment_n)

*Table V - Time spent by answer type regressions
reg crttime_pagesubmit crtincorrect crtcorrect black asian other hispanic high_income advanced_degree if time_constraint==0 & gain==0 & loss==0, r
lincom crtincorrect-crtcorrect
est sto Tr1

reg crttime_pagesubmit crtincorrect crtcorrect black asian other hispanic high_income advanced_degree if time_constraint==0 & gain==1 & loss==0, r
lincom crtincorrect-crtcorrect
est sto Tr2

reg crttime_pagesubmit crtincorrect crtcorrect black asian other hispanic high_income advanced_degree if time_constraint==0 & gain==0 & loss==1, r
lincom crtincorrect-crtcorrect
est sto Tr3

esttab Tr1 Tr2 Tr3, compress ar2 b(%10.3fc) se(%10.3fc) nonotes addnotes("Dependent variable is time spent answering (in seconds)." "Controls include race, education and income." "OLS with robust standard errors reported." "* p<0.10, ** p<0.05, *** p<0.01.") label replace star(* 0.105 ** 0.055 *** 0.015) /*
	*/ drop(black asian other hispanic high_income advanced_degree) mtitles("None" "Gains" "Losses") title("The effect of gains and losses on transitioning from intuitive to correct.") /*
	*/ order()
	
*Figure 6 - Mean intuitive young men
g young_men = 0
replace young_men = 1 if female == 0 & age<35
tab young_men

g g_ym = gain * young_men
g l_ym = loss * young_men

cibar crtintuit if time_constraint==0, over1(treatment_n) over2(young_men)

*Table VII - Young men regressions
reg crtintuit gain loss if time_constraint==0 & young_men==0, r
lincom gain-loss
est sto I1

reg crtintuit gain loss if time_constraint==0 & young_men==1, r
lincom gain-loss
est sto I2

reg crtintuit gain loss young_men g_ym l_ym if time_constraint==0, r
lincom gain + g_ym
lincom loss + l_ym
est sto I3

reg crtintuit gain loss young_men g_ym l_ym black asian other hispanic high_income advanced_degree if time_constraint==0, r
lincom gain + g_ym
lincom loss + l_ym
est sto I4

esttab I3 I4, compress ar2 b(%10.3fc) se(%10.3fc) nonotes addnotes("Dependent variable is an intuitive response indicator." "OLS with robust standard errors reported." "Controls include race, income and education." "* p<0.10, ** p<0.05, *** p<0.01.") label replace star(* 0.105 ** 0.055 *** 0.015) /*
	*/ drop(black asian other hispanic high_income advanced_degree) mtitles() title("The differential effect of losses on thinking intuitively among young men.") /*
	*/ order()	

*Figure 9 - Young men intuitive with time constraint
cibar crtintuit if time_constraint==1, over1(treatment_n) over2(young_men)	
	
*Cognitive Load Stuff
g nasa_sum = nasa_1 + nasa_2 + nasa_3 + nasa_6
codebook nasa_sum
g nasa_big = nasa_sum > 22
*Figure 7b - Mean intuitive by NASA temporal demand	
cibar crtintuit, over1(nasa_big)
*Figure 7a - Effect of time constraint on NASA temporal demand
cibar nasa_2, over1(time_constraint)

*Figure 8 - Time constraint hinders intuitive
cibar crtintuit, over1(treatment_n) over2(time_constraint)

*Table IX - Time constraint hinders intuitive regressions
reg crtintuit gain loss time_constraint gainXtime lossXtime, r
lincom gain-loss
lincom gain+gainXtime
lincom loss+lossXtime
est sto I1

reg crtintuit gain loss time_constraint gainXtime lossXtime black asian other hispanic high_income advanced_degree, r
lincom gain-loss
lincom gain+gainXtime
lincom loss+lossXtime
est sto I2

esttab I1 I2, compress ar2 b(%10.3fc) se(%10.3fc) nonotes addnotes("Dependent variable is an intuitive response indicator." "OLS with robust standard errors reported." "Controls include race, income and education." "* p<0.10, ** p<0.05, *** p<0.01.") label replace star(* 0.105 ** 0.055 *** 0.015) /*
	*/ drop(black asian other hispanic high_income advanced_degree) mtitles() title("The differential effect of a cognitive load on thinking intuitively.") /*
	*/ order()	
	
*Other Robustness Checks -- Aggregated Data

clear
u "`c(pwd)'/Data/S1S2_Losses.dta", clear

***** Create some variables *****
g treatment = fl_6_do

g treatment_n = 0
replace treatment_n = 1 if fl_6_do == "GainTreatment"
replace treatment_n = 2 if fl_6_do == "LossTreatment"
label define treat 0 "None" 1 "Gain" 2 "Loss"
label values treatment_n treat

g loss = treatment_n == 2
g gain = treatment_n == 1

g crt_correct = crt1_correct + crt2_correct + crt3_correct + crt4_correct + crt5_correct + crt6_correct + crt7_correct
sum crt_correct

g crt_intuit = crt1_intuit + crt2_intuit + crt3_intuit + crt4_intuit + crt5_intuit + crt6_intuit + crt7_intuit
sum crt_intuit

g crt_time = crt1time_pagesubmit + crt2time_pagesubmit + crt3time_pagesubmit + crt4time_pagesubmit + crt5time_pagesubmit +crt6time_pagesubmit + crt7time_pagesubmit
sum crt_time

g female = gender == "Female"
g nonbinary = gender == "Non-binary"

g black = race == "Black or African American"
g asian = race == "Asian"
g other = race == "American Indian or Alaska Native" | race == "Native Hawaiian or Pacific Islander" | race == "Other" | race == "Prefer not to disclose"

g hispanic = spanishhispanic == "Yes"

g college_or_more = education == "Bachelor's degree in college (4-year)" | education == "Master's degree" | education == "Professional degree (JD, MD)" | education == "Doctoral degree"

g advanced_degree = education == "Master's degree" | education == "Professional degree (JD, MD)" | education == "Doctoral degree"

g high_income = income == "$50,000 to $74,999" | income == "$75,000 to $99,999" | income == "$100,000 or more"

g gainXtime = time_constraint * gain
g lossXtime = time_constraint * loss

*Table VI - Regressions with aggregated data
reg crt_time gain loss if time_constraint==0, r
lincom gain-loss
est sto T1

reg crt_time gain loss black asian other hispanic high_income advanced_degree if time_constraint==0, r
lincom gain-loss
est sto T2

nbreg crt_correct gain loss if time_constraint==0, r
lincom gain-loss
est sto C1

nbreg crt_correct gain loss black asian other hispanic high_income advanced_degree if time_constraint==0, r
lincom gain-loss
est sto C2


nbreg crt_intuit gain loss if time_constraint==0, r
lincom gain-loss
est sto I1

nbreg crt_intuit gain loss black asian other hispanic high_income advanced_degree if time_constraint==0, r
lincom gain-loss
est sto I2

esttab T1 T2 C1 C2 I1 I2, compress ar2 b(%10.3fc) se(%10.3fc) nonotes addnotes("Dependent variable varies between total time spent, number of correct responses and number of intuitive responses." "OLS or negative binomial with robust standard errors reported." "Controls include race, income and education."  "* p<0.10, ** p<0.05, *** p<0.01.") label replace star(* 0.105 ** 0.055 *** 0.015) /*
	*/ drop(black asian other hispanic high_income advanced_degree) mtitles() title("Treatment effects using aggregated data.") /*
	*/ order()

**** END OF FILE
